Improving saruman: report bugs, fork on github or email us
==========================================================

Did you find a bug? Do you have an improvement? Do you have questions? We run
*saruman* as a proper open source project on github at
https://github.com/tychota/saruman, so you have three basic
options:

- Report bugs or problems at https://github.com/tychota/saruman/issues ! And feature requests too !
  Normally you'll get a quick reply within a day or so,
  depending on our relative timezones. If you don't get an answer within a few
  days, please send off a quick email to remind us.

- Or make a fork, fix the bug or add something and open a pull request.

  *If* you are going to fork saruman, take a look at :doc:`developing`  for
  setup and test running information.

- You can mail  `Tycho Tatitscheff <mailto://tycho.tatitscheff+saruman@gadz.org>`_ if you want to ask a question, too.
  Or if you want to tell us about an idea you have.


.. include:: ../../CREDITS.rst
